@@ -16,7 +16,8 @@ Randall Romero Aguilar
 """
 
 
-import dash
+
+from jupyter_dash import JupyterDash
 import dash_core_components as dcc
 import dash_html_components as html
 from dash.dependencies import Input, Output, State
@@ -372,8 +373,8 @@ def app_parameter_row(label, appid, inputtype, value, size='20'): # to make inpu
     return html.Tr([*app_parameter(label, appid, inputtype, value, size)])
 
 
-app = dash.Dash(__name__,external_stylesheets=external_stylesheets, external_scripts=mathjax)  # main application
 
+app = JupyterDash(__name__,external_stylesheets=external_stylesheets, external_scripts=mathjax)
 
 #======DESIGN THE APP===============
 
@@ -508,9 +509,14 @@ def show_pq_options(showestimates, phi, theta):
     return children, style
 
 
-def ARMA_demo():
-    webbrowser.open('http://127.0.0.1:8050/')
-    app.run_server(debug=False)
+
+
+def ARMA_demo(colab=True):
+    if colab:
+        app.run_server(mode='external')
+    else:
+        webbrowser.open('http://127.0.0.1:8050/')
+        app.run_server(debug=False)
 
 
 if __name__ == '__main__':
