@@ -3,7 +3,8 @@
 
 
 
-import dash
+
+from jupyter_dash import JupyterDash
 import dash_core_components as dcc
 import dash_html_components as html
 from dash.dependencies import Input, Output, State
@@ -136,8 +137,8 @@ def app_model_parameter(label, base_value, scen_value): # to make input paramete
     return html.Tr([txt, param1, param2])
 
 
-app = dash.Dash(__name__,external_stylesheets=external_stylesheets, external_scripts=mathjax)  # main application
 
+app = JupyterDash(__name__,external_stylesheets=external_stylesheets, external_scripts=mathjax)
 
 #======DESIGN THE APP===============
 
@@ -221,11 +222,12 @@ def update_ARMA_parameters(n_clicks,T, α, δ, n, A, s, α1, δ1, n1, A1, s1):
 
 
 
-
-def Solow_demo():
-    webbrowser.open('http://127.0.0.1:8050/')
-    app.run_server(debug=False)
-
+def Solow_demo(colab=True):
+    if colab:
+        app.run_server(mode='external')
+    else:
+        webbrowser.open('http://127.0.0.1:8050/')
+        app.run_server(debug=False)
 
 if __name__ == '__main__':
     Solow_demo()
\ No newline at end of file
